pub struct DependencyDiagnosticReport { /* private fields */ }Expand description
This struct defines an individual dependency diagnostic result.
Implementations
Sourceimpl DependencyDiagnosticReport
impl DependencyDiagnosticReport
Sourcepub fn cells_affected(&self) -> &Vec<(i32, i32)>
pub fn cells_affected(&self) -> &Vec<(i32, i32)>
List of cells, in “row, column” format.
If the full row or full column are affected, use -1.
pub fn report_type(&self) -> &DependencyDiagnosticReportType
Sourceimpl DependencyDiagnosticReport
impl DependencyDiagnosticReport
Sourcepub fn cells_affected_mut(&mut self) -> &mut Vec<(i32, i32)>
pub fn cells_affected_mut(&mut self) -> &mut Vec<(i32, i32)>
List of cells, in “row, column” format.
If the full row or full column are affected, use -1.
pub fn report_type_mut(&mut self) -> &mut DependencyDiagnosticReportType
Sourceimpl DependencyDiagnosticReport
impl DependencyDiagnosticReport
pub fn new( report_type: DependencyDiagnosticReportType, cells_affected: &[(i32, i32)], ) -> Self