pub struct TableDiagnostic { /* private fields */ }Expand description
This struct contains the results of a Table diagnostic.
Implementations
Sourceimpl TableDiagnostic
impl TableDiagnostic
pub fn path_mut(&mut self) -> &mut String
pub fn pack_mut(&mut self) -> &mut String
pub fn results_mut(&mut self) -> &mut Vec<TableDiagnosticReport>
Sourceimpl TableDiagnostic
impl TableDiagnostic
pub fn new(path: &str, pack: &str) -> Self
Sourcepub fn check_db(
files: &[(&str, &RFile)],
dependencies: &Dependencies,
global_ignored_diagnostics: &[String],
game_info: &GameInfo,
local_path_list: &HashMap<String, Vec<String>>,
check_ak_only_refs: bool,
files_to_ignore: &Option<Vec<(String, Vec<String>, Vec<String>)>>,
packs: &BTreeMap<String, Pack>,
schema: &Schema,
loc_data: &Option<HashMap<Cow<'_, str>, Cow<'_, str>>>,
) -> Vec<DiagnosticType>
pub fn check_db( files: &[(&str, &RFile)], dependencies: &Dependencies, global_ignored_diagnostics: &[String], game_info: &GameInfo, local_path_list: &HashMap<String, Vec<String>>, check_ak_only_refs: bool, files_to_ignore: &Option<Vec<(String, Vec<String>, Vec<String>)>>, packs: &BTreeMap<String, Pack>, schema: &Schema, loc_data: &Option<HashMap<Cow<'_, str>, Cow<'_, str>>>, ) -> Vec<DiagnosticType>
This function takes care of checking the db tables of your mod for errors.