pub struct TableDiagnosticReport { /* private fields */ }Expand description
This struct defines an individual table diagnostic result.
Implementations
Sourceimpl TableDiagnosticReport
impl TableDiagnosticReport
Sourcepub fn cells_affected(&self) -> &Vec<(i32, i32)>
pub fn cells_affected(&self) -> &Vec<(i32, i32)>
List of cells, in “row, column” format.
If the full row or full column are affected, use -1.
Sourcepub fn column_names(&self) -> &Vec<String>
pub fn column_names(&self) -> &Vec<String>
Name of the columns that corresponds to the affected cells.
pub fn report_type(&self) -> &TableDiagnosticReportType
Sourceimpl TableDiagnosticReport
impl TableDiagnosticReport
Sourcepub fn cells_affected_mut(&mut self) -> &mut Vec<(i32, i32)>
pub fn cells_affected_mut(&mut self) -> &mut Vec<(i32, i32)>
List of cells, in “row, column” format.
If the full row or full column are affected, use -1.
Sourcepub fn column_names_mut(&mut self) -> &mut Vec<String>
pub fn column_names_mut(&mut self) -> &mut Vec<String>
Name of the columns that corresponds to the affected cells.
pub fn report_type_mut(&mut self) -> &mut TableDiagnosticReportType