pub enum LuaIssueKind {
SyntaxError(String),
UnknownMethod(String, String),
WrongArgumentCount(String, usize, Option<usize>, usize),
UnknownEvent(String),
}Expand description
Kinds of problems found in scripts.
Variants
SyntaxError(String)
The script can’t be parsed. Contains the parser’s message.
UnknownMethod(String, String)
A method not documented for the type it’s called on. Contains the type and the method.
WrongArgumentCount(String, usize, Option<usize>, usize)
A documented function called with the wrong amount of arguments. Contains the function, the minimum and maximum (if any) amount of arguments it takes, and the amount passed.
UnknownEvent(String)
A listener for an event that doesn’t exist. Contains the event.