run_tests

Function run_tests 

pub fn run_tests(
    api: &LuaApi,
    scripts: &LuaScripts,
    test_source: &str,
    options: &LuaTestOptions,
) -> Result<LuaTestReport>
This function runs the tests of a test file.

Arguments

  • api - API of the game, whose docs type the engine objects.
  • scripts - Scripts of the game and of the tested packs.
  • test_source - Code of the test file.
  • options - Options of the run.

Returns

The result of each test.

Errors

Returns an error if the game’s scripts are missing, if the test file can’t be loaded, or if the Lua runtime fails.