pub struct LuaTestOptions { /* private fields */ }Expand description
Options of a test run.
Implementations
Sourceimpl LuaTestOptions
impl LuaTestOptions
Sourcepub fn campaign(&self) -> &Option<String>
pub fn campaign(&self) -> &Option<String>
Campaign whose vanilla scripts to load, like main_warhammer. If None, only the script libraries and
the mods are loaded, which is faster and less affected by engine behavior the harness doesn’t emulate.
Sourcepub fn faction_keys(&self) -> &Vec<String>
pub fn faction_keys(&self) -> &Vec<String>
Keys of the factions in the game’s DB. Scripts looking them up get a faction even if tests didn’t set it up.
Sourcepub fn region_keys(&self) -> &Vec<String>
pub fn region_keys(&self) -> &Vec<String>
Keys of the regions in the game’s DB. Scripts looking them up get a region even if tests didn’t set it up.
Sourceimpl LuaTestOptions
impl LuaTestOptions
Sourcepub fn set_campaign(&mut self, val: Option<String>) -> &mut Self
pub fn set_campaign(&mut self, val: Option<String>) -> &mut Self
Campaign whose vanilla scripts to load, like main_warhammer. If None, only the script libraries and
the mods are loaded, which is faster and less affected by engine behavior the harness doesn’t emulate.
Sourcepub fn set_faction_keys(&mut self, val: Vec<String>) -> &mut Self
pub fn set_faction_keys(&mut self, val: Vec<String>) -> &mut Self
Keys of the factions in the game’s DB. Scripts looking them up get a faction even if tests didn’t set it up.
Sourcepub fn set_region_keys(&mut self, val: Vec<String>) -> &mut Self
pub fn set_region_keys(&mut self, val: Vec<String>) -> &mut Self
Keys of the regions in the game’s DB. Scripts looking them up get a region even if tests didn’t set it up.