pub struct OptimizerOptions { /* private fields */ }Expand description
Struct containing the configurable options for the optimizer.
Implementations
Sourceimpl OptimizerOptions
impl OptimizerOptions
Sourcepub fn set_optimize_datacored_tables(&mut self, enable: bool) -> &mut Self
pub fn set_optimize_datacored_tables(&mut self, enable: bool) -> &mut Self
Allow the optimizer to optimize datacored tables.
THIS IS NOT RECOMMENDED, as datacored tables usually are they way they are for a reason.
Sourcepub fn set_remove_unused_art_sets(&mut self, enable: bool) -> &mut Self
pub fn set_remove_unused_art_sets(&mut self, enable: bool) -> &mut Self
Allow the optimizer to remove unused art sets in Portrait Settings files.
Only use this after you have confirmed the unused art sets are actually unused and not caused by a typo.
Sourcepub fn set_remove_unused_variants(&mut self, enable: bool) -> &mut Self
pub fn set_remove_unused_variants(&mut self, enable: bool) -> &mut Self
Allow the optimizer to remove unused variants from art sets in Portrait Settings files.
Only use this after you have confirmed the unused variants are actually unused and not caused by a typo.
Sourcepub fn set_remove_empty_masks(&mut self, enable: bool) -> &mut Self
pub fn set_remove_empty_masks(&mut self, enable: bool) -> &mut Self
Allow the optimizer to remove empty masks in Portrait Settings file, reducing their side.
Ingame there’s no difference between an empty mask and an invalid one, so it’s better to remove them to reduce their size.