pub struct AnimFragmentBattleMatch { /* private fields */ }Expand description
This struct represents a match within an Anim Fragment Battle File.
Implementations
Sourceimpl AnimFragmentBattleMatch
impl AnimFragmentBattleMatch
Sourcepub fn skeleton_name(&self) -> &bool
pub fn skeleton_name(&self) -> &bool
If the match corresponds to a skeleton name value.
Sourcepub fn table_name(&self) -> &bool
pub fn table_name(&self) -> &bool
If the match corresponds to a table name value.
Sourcepub fn mount_table_name(&self) -> &bool
pub fn mount_table_name(&self) -> &bool
If the match corresponds to a mount table name value.
Sourcepub fn unmount_table_name(&self) -> &bool
pub fn unmount_table_name(&self) -> &bool
If the match corresponds to a unmount table name value.
Sourcepub fn locomotion_graph(&self) -> &bool
pub fn locomotion_graph(&self) -> &bool
If the match corresponds to a locomotion table name value.
Sourceimpl AnimFragmentBattleMatch
impl AnimFragmentBattleMatch
Sourcepub fn skeleton_name_mut(&mut self) -> &mut bool
pub fn skeleton_name_mut(&mut self) -> &mut bool
If the match corresponds to a skeleton name value.
Sourcepub fn table_name_mut(&mut self) -> &mut bool
pub fn table_name_mut(&mut self) -> &mut bool
If the match corresponds to a table name value.
Sourcepub fn mount_table_name_mut(&mut self) -> &mut bool
pub fn mount_table_name_mut(&mut self) -> &mut bool
If the match corresponds to a mount table name value.
Sourcepub fn unmount_table_name_mut(&mut self) -> &mut bool
pub fn unmount_table_name_mut(&mut self) -> &mut bool
If the match corresponds to a unmount table name value.
Sourcepub fn locomotion_graph_mut(&mut self) -> &mut bool
pub fn locomotion_graph_mut(&mut self) -> &mut bool
If the match corresponds to a locomotion table name value.
Sourceimpl AnimFragmentBattleMatch
impl AnimFragmentBattleMatch
Sourcepub fn new(
skeleton_name: bool,
table_name: bool,
mount_table_name: bool,
unmount_table_name: bool,
locomotion_graph: bool,
entry: Option<(usize, Option<(usize, bool, bool, bool)>, bool, bool, bool, bool, bool)>,
start: usize,
end: usize,
text: String,
) -> Self
pub fn new( skeleton_name: bool, table_name: bool, mount_table_name: bool, unmount_table_name: bool, locomotion_graph: bool, entry: Option<(usize, Option<(usize, bool, bool, bool)>, bool, bool, bool, bool, bool)>, start: usize, end: usize, text: String, ) -> Self
This function creates a new AnimFragmentBattleMatch with the provided data.