pub struct AtlasMatch { /* private fields */ }Expand description
This struct represents a match within an Atlas File.
Implementations
Sourceimpl AtlasMatch
impl AtlasMatch
Sourcepub fn column_name(&self) -> &String
pub fn column_name(&self) -> &String
The name of the column where the match is.
Sourcepub fn column_number(&self) -> &u32
pub fn column_number(&self) -> &u32
The logical index of the column where the match is.
Sourcepub fn row_number(&self) -> &i64
pub fn row_number(&self) -> &i64
The row number of this match.
Sourceimpl AtlasMatch
impl AtlasMatch
Sourcepub fn column_name_mut(&mut self) -> &mut String
pub fn column_name_mut(&mut self) -> &mut String
The name of the column where the match is.
Sourcepub fn column_number_mut(&mut self) -> &mut u32
pub fn column_number_mut(&mut self) -> &mut u32
The logical index of the column where the match is.
Sourcepub fn row_number_mut(&mut self) -> &mut i64
pub fn row_number_mut(&mut self) -> &mut i64
The row number of this match.