pub struct PortraitSettingsMatch { /* private fields */ }Expand description
This struct represents a match within an PortraitSettings File.
Implementations
Sourceimpl PortraitSettingsMatch
impl PortraitSettingsMatch
Sourcepub fn entry(&self) -> &usize
pub fn entry(&self) -> &usize
The index of the entry in question in the PortraitSettings file. Not sure if the ids are unique, so we use the index.
Sourcepub fn camera_settings_head(&self) -> &bool
pub fn camera_settings_head(&self) -> &bool
If the match corresponds to a camera settings head (skeleton node) value.
Sourcepub fn camera_settings_body(&self) -> &bool
pub fn camera_settings_body(&self) -> &bool
If the match corresponds to a camera settings body (skeleton node) value.
Sourceimpl PortraitSettingsMatch
impl PortraitSettingsMatch
Sourcepub fn entry_mut(&mut self) -> &mut usize
pub fn entry_mut(&mut self) -> &mut usize
The index of the entry in question in the PortraitSettings file. Not sure if the ids are unique, so we use the index.
Sourcepub fn camera_settings_head_mut(&mut self) -> &mut bool
pub fn camera_settings_head_mut(&mut self) -> &mut bool
If the match corresponds to a camera settings head (skeleton node) value.
Sourcepub fn camera_settings_body_mut(&mut self) -> &mut bool
pub fn camera_settings_body_mut(&mut self) -> &mut bool
If the match corresponds to a camera settings body (skeleton node) value.