pub struct RigidModelMatch { /* private fields */ }Expand description
This struct represents a match within an RigidModel File.
Implementations
Sourceimpl RigidModelMatch
impl RigidModelMatch
Sourcepub fn skeleton_id(&self) -> &bool
pub fn skeleton_id(&self) -> &bool
If the match is in the skeleton id of the rigid.
Sourcepub fn mesh_value(&self) -> &Option<(i32, i32)>
pub fn mesh_value(&self) -> &Option<(i32, i32)>
If the match is inside a mesh. The values are
- Lod index.
- Mesh index.
Sourcepub fn mesh_mat_name(&self) -> &bool
pub fn mesh_mat_name(&self) -> &bool
If the match is in the name of the material.
Sourcepub fn mesh_textute_directory(&self) -> &bool
pub fn mesh_textute_directory(&self) -> &bool
If the match is in the texture directory of a mesh.
Sourcepub fn mesh_filters(&self) -> &bool
pub fn mesh_filters(&self) -> &bool
If the match is in the filters of a mesh.
Sourcepub fn mesh_att_point_name(&self) -> &Option<i32>
pub fn mesh_att_point_name(&self) -> &Option<i32>
If the match is in the name of one of the attachment points of a mesh.
Sourcepub fn mesh_texture_path(&self) -> &Option<i32>
pub fn mesh_texture_path(&self) -> &Option<i32>
If the match is in the name of one of the texture paths of a mesh.
Sourceimpl RigidModelMatch
impl RigidModelMatch
Sourcepub fn skeleton_id_mut(&mut self) -> &mut bool
pub fn skeleton_id_mut(&mut self) -> &mut bool
If the match is in the skeleton id of the rigid.
Sourcepub fn mesh_value_mut(&mut self) -> &mut Option<(i32, i32)>
pub fn mesh_value_mut(&mut self) -> &mut Option<(i32, i32)>
If the match is inside a mesh. The values are
- Lod index.
- Mesh index.
Sourcepub fn mesh_name_mut(&mut self) -> &mut bool
pub fn mesh_name_mut(&mut self) -> &mut bool
If the match is in the name of a mesh.
Sourcepub fn mesh_mat_name_mut(&mut self) -> &mut bool
pub fn mesh_mat_name_mut(&mut self) -> &mut bool
If the match is in the name of the material.
Sourcepub fn mesh_textute_directory_mut(&mut self) -> &mut bool
pub fn mesh_textute_directory_mut(&mut self) -> &mut bool
If the match is in the texture directory of a mesh.
Sourcepub fn mesh_filters_mut(&mut self) -> &mut bool
pub fn mesh_filters_mut(&mut self) -> &mut bool
If the match is in the filters of a mesh.
Sourcepub fn mesh_att_point_name_mut(&mut self) -> &mut Option<i32>
pub fn mesh_att_point_name_mut(&mut self) -> &mut Option<i32>
If the match is in the name of one of the attachment points of a mesh.
Sourcepub fn mesh_texture_path_mut(&mut self) -> &mut Option<i32>
pub fn mesh_texture_path_mut(&mut self) -> &mut Option<i32>
If the match is in the name of one of the texture paths of a mesh.
Sourceimpl RigidModelMatch
impl RigidModelMatch
Sourcepub fn new(
skeleton_id: bool,
mesh_value: Option<(i32, i32)>,
mesh_name: bool,
mesh_mat_name: bool,
mesh_textute_directory: bool,
mesh_filters: bool,
mesh_att_point_name: Option<i32>,
mesh_texture_path: Option<i32>,
start: usize,
end: usize,
data: String,
) -> Self
pub fn new( skeleton_id: bool, mesh_value: Option<(i32, i32)>, mesh_name: bool, mesh_mat_name: bool, mesh_textute_directory: bool, mesh_filters: bool, mesh_att_point_name: Option<i32>, mesh_texture_path: Option<i32>, start: usize, end: usize, data: String, ) -> Self
This function creates a new RigidModelMatch with the provided data.