pub struct SearchOn { /* private fields */ }Expand description
Configuration for which file types to include in a search.
Each boolean field controls whether that file type will be searched.
Use SearchOn::all() to enable all file types or configure individually.
Implementations
Sourceimpl SearchOn
impl SearchOn
pub fn anim(&self) -> &bool
pub fn anim_fragment_battle(&self) -> &bool
pub fn anim_pack(&self) -> &bool
pub fn anims_table(&self) -> &bool
pub fn atlas(&self) -> &bool
pub fn audio(&self) -> &bool
pub fn bmd(&self) -> &bool
pub fn db(&self) -> &bool
pub fn esf(&self) -> &bool
pub fn group_formations(&self) -> &bool
pub fn image(&self) -> &bool
pub fn loc(&self) -> &bool
pub fn matched_combat(&self) -> &bool
pub fn pack(&self) -> &bool
pub fn portrait_settings(&self) -> &bool
pub fn rigid_model(&self) -> &bool
pub fn sound_bank(&self) -> &bool
pub fn text(&self) -> &bool
pub fn uic(&self) -> &bool
pub fn unit_variant(&self) -> &bool
pub fn unknown(&self) -> &bool
pub fn video(&self) -> &bool
pub fn schema(&self) -> &bool
Sourceimpl SearchOn
impl SearchOn
pub fn set_anim(&mut self, val: bool) -> &mut Self
pub fn set_anim_fragment_battle(&mut self, val: bool) -> &mut Self
pub fn set_anim_pack(&mut self, val: bool) -> &mut Self
pub fn set_anims_table(&mut self, val: bool) -> &mut Self
pub fn set_atlas(&mut self, val: bool) -> &mut Self
pub fn set_audio(&mut self, val: bool) -> &mut Self
pub fn set_bmd(&mut self, val: bool) -> &mut Self
pub fn set_db(&mut self, val: bool) -> &mut Self
pub fn set_esf(&mut self, val: bool) -> &mut Self
pub fn set_group_formations(&mut self, val: bool) -> &mut Self
pub fn set_image(&mut self, val: bool) -> &mut Self
pub fn set_loc(&mut self, val: bool) -> &mut Self
pub fn set_matched_combat(&mut self, val: bool) -> &mut Self
pub fn set_pack(&mut self, val: bool) -> &mut Self
pub fn set_portrait_settings(&mut self, val: bool) -> &mut Self
pub fn set_rigid_model(&mut self, val: bool) -> &mut Self
pub fn set_sound_bank(&mut self, val: bool) -> &mut Self
pub fn set_text(&mut self, val: bool) -> &mut Self
pub fn set_uic(&mut self, val: bool) -> &mut Self
pub fn set_unit_variant(&mut self, val: bool) -> &mut Self
pub fn set_unknown(&mut self, val: bool) -> &mut Self
pub fn set_video(&mut self, val: bool) -> &mut Self
pub fn set_schema(&mut self, val: bool) -> &mut Self