pub struct UnitVariantMatch { /* private fields */ }Expand description
This struct represents a match within an UnitVariant File.
Implementations
Sourceimpl UnitVariantMatch
impl UnitVariantMatch
Sourceimpl UnitVariantMatch
impl UnitVariantMatch
Sourcepub fn entry_mut(&mut self) -> &mut usize
pub fn entry_mut(&mut self) -> &mut usize
The index of the entry in question in the UnitVariant file. Not sure if the ids are unique, so we use the index.