pub struct HubSubmission { /* private fields */ }Expand description
Everything needed to submit a translation to the Translation Hub as a pull request.
Implementations
Sourceimpl HubSubmission
impl HubSubmission
Sourcepub fn replaced_path(&self) -> &Option<String>
pub fn replaced_path(&self) -> &Option<String>
Path of the same translation in the other format version, to delete from the hub if it’s there.
Sourcepub fn branch(&self) -> &String
pub fn branch(&self) -> &String
Branch the submission is pushed to. It’s the same for every submission of the same translation.
Sourcepub fn commit_message(&self) -> &String
pub fn commit_message(&self) -> &String
Message of the submission’s commit.