OptimizerOptions

Struct OptimizerOptions 

pub struct OptimizerOptions { /* private fields */ }
Configuration options for the pack optimizer.

Controls which optimization operations are enabled. Each option can be individually toggled to customize the optimization behavior.

Default Behavior

By default, safe optimizations are enabled (duplicate removal, ITM removal) while potentially destructive ones are disabled (datacored table optimization, unused art set removal).

Implementations

Source

impl OptimizerOptions

pub fn pack_remove_itm_files(&self) -> &bool

Allow the optimizer to remove files unchanged from vanilla, reducing the pack size.

pub fn pack_apply_compression(&self) -> &bool

Allow the optimizer to apply the most modern compression format the active game supports, so the next save compresses the files.

Overrides whatever format the pack had configured. Intended as a final step before release on a pack that’s been edited uncompressed. No-op if the active game supports no compression formats.

pub fn db_import_datacores_into_twad_key_deletes(&self) -> &bool

Allows the optimizer to update the twad_key_deletes table using the data cored tables in your pack to guess the keys.

IT DOESN’T DELETE THE DATACORED TABLES.

pub fn db_optimize_datacored_tables(&self) -> &bool

Allow the optimizer to optimize datacored tables. THIS IS NOT RECOMMENDED, as datacored tables usually are they way they are for a reason.

THIS IS NOT RECOMMENDED, as datacored tables usually are the way they are for a reason.

pub fn table_remove_duplicated_entries(&self) -> &bool

Allows the optimizer to remove duplicated rows from db and loc files.

pub fn table_remove_itm_entries(&self) -> &bool

Allows the optimizer to remove ITM (Identical To Master) rows from db and loc files.

pub fn table_remove_itnr_entries(&self) -> &bool

Allows the optimizer to remove ITNR (Identical To New Row) rows from db and loc files.

pub fn table_remove_empty_file(&self) -> &bool

Allows the optimizer to remove empty db and loc files.

pub fn text_remove_unused_xml_map_folders(&self) -> &bool

Allows the optimizer to remove unused xml files in map folders.

pub fn text_remove_unused_xml_prefab_folder(&self) -> &bool

Allows the optimizer to remove unused xml files in the prefab folder.

pub fn text_remove_agf_files(&self) -> &bool

Allows the optimizer to remove unused agf files.

pub fn text_remove_model_statistics_files(&self) -> &bool

Allows the optimizer to remove unused model_statistics files.

pub fn pts_remove_unused_art_sets(&self) -> &bool

Allow the optimizer to remove unused art sets in Portrait Settings files.

Only use this after you have confirmed the unused art sets are actually unused and not caused by a typo.

pub fn pts_remove_unused_variants(&self) -> &bool

Allow the optimizer to remove unused variants from art sets in Portrait Settings files.

Only use this after you have confirmed the unused variants are actually unused and not caused by a typo.

pub fn pts_remove_empty_masks(&self) -> &bool

Allow the optimizer to remove empty masks in Portrait Settings file, reducing their side.

Ingame there’s no difference between an empty mask and an invalid one, so it’s better to remove them to reduce their size.

pub fn pts_remove_empty_file(&self) -> &bool

Allows the optimizer to remove empty Portrait Settings files.

Source

impl OptimizerOptions

pub fn set_pack_remove_itm_files(&mut self, val: bool) -> &mut Self

Allow the optimizer to remove files unchanged from vanilla, reducing the pack size.

pub fn set_pack_apply_compression(&mut self, val: bool) -> &mut Self

Allow the optimizer to apply the most modern compression format the active game supports, so the next save compresses the files.

Overrides whatever format the pack had configured. Intended as a final step before release on a pack that’s been edited uncompressed. No-op if the active game supports no compression formats.

pub fn set_db_import_datacores_into_twad_key_deletes( &mut self, val: bool, ) -> &mut Self

Allows the optimizer to update the twad_key_deletes table using the data cored tables in your pack to guess the keys.

IT DOESN’T DELETE THE DATACORED TABLES.

pub fn set_db_optimize_datacored_tables(&mut self, val: bool) -> &mut Self

Allow the optimizer to optimize datacored tables. THIS IS NOT RECOMMENDED, as datacored tables usually are they way they are for a reason.

THIS IS NOT RECOMMENDED, as datacored tables usually are the way they are for a reason.

pub fn set_table_remove_duplicated_entries(&mut self, val: bool) -> &mut Self

Allows the optimizer to remove duplicated rows from db and loc files.

pub fn set_table_remove_itm_entries(&mut self, val: bool) -> &mut Self

Allows the optimizer to remove ITM (Identical To Master) rows from db and loc files.

pub fn set_table_remove_itnr_entries(&mut self, val: bool) -> &mut Self

Allows the optimizer to remove ITNR (Identical To New Row) rows from db and loc files.

pub fn set_table_remove_empty_file(&mut self, val: bool) -> &mut Self

Allows the optimizer to remove empty db and loc files.

pub fn set_text_remove_unused_xml_map_folders(&mut self, val: bool) -> &mut Self

Allows the optimizer to remove unused xml files in map folders.

pub fn set_text_remove_unused_xml_prefab_folder( &mut self, val: bool, ) -> &mut Self

Allows the optimizer to remove unused xml files in the prefab folder.

pub fn set_text_remove_agf_files(&mut self, val: bool) -> &mut Self

Allows the optimizer to remove unused agf files.

pub fn set_text_remove_model_statistics_files(&mut self, val: bool) -> &mut Self

Allows the optimizer to remove unused model_statistics files.

pub fn set_pts_remove_unused_art_sets(&mut self, val: bool) -> &mut Self

Allow the optimizer to remove unused art sets in Portrait Settings files.

Only use this after you have confirmed the unused art sets are actually unused and not caused by a typo.

pub fn set_pts_remove_unused_variants(&mut self, val: bool) -> &mut Self

Allow the optimizer to remove unused variants from art sets in Portrait Settings files.

Only use this after you have confirmed the unused variants are actually unused and not caused by a typo.

pub fn set_pts_remove_empty_masks(&mut self, val: bool) -> &mut Self

Allow the optimizer to remove empty masks in Portrait Settings file, reducing their side.

Ingame there’s no difference between an empty mask and an invalid one, so it’s better to remove them to reduce their size.

pub fn set_pts_remove_empty_file(&mut self, val: bool) -> &mut Self

Allows the optimizer to remove empty Portrait Settings files.